@@ -1,6 +1,6 @@
 """Model class for metadata regarding the package info available to `omniversion`."""
 import os
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 from .config import ConfigDataSource
 from .file import FileDataSource
@@ -135,14 +135,13 @@ class DataSources:
         return sorted(list({file.host for file in self.files}))
 
     @property
-    def host_infos(self) -> List[tuple[str, List[FileDataSource], List[ConfigDataSource]]]:
+    def host_infos(self) -> List[Tuple[str, List[FileDataSource], List[ConfigDataSource]]]:
         """List of host information, containing the hostname, a list of `.omniversion.yaml` files and a list of
         configuration files from which packages have been loaded.
         """
         def item_for_host(hostname: str):
-            files = [file for file in self.files if file.host == hostname]
-            configs = [config for config in self.configs if config.host == hostname]
-            return hostname, files, configs
+            sources_for_host = self.for_host(hostname=hostname)
+            return hostname, sources_for_host.files, sources_for_host.configs
         return [item_for_host(hostname) for hostname in self.hostnames]
 
     @property
@@ -150,6 +149,14 @@ class DataSources:
         """Deduplicated list of hosts for which files are present in the list."""
         return sorted(list({file.package_manager for file in self.files}))
 
+    def for_host(self, hostname: str) -> 'DataSources':
+        files = [file for file in self.files if file.host == hostname]
+        configs = [config for config in self.configs if config.host == hostname]
+        return DataSources(files=files, configs=configs)
+
+    def __len__(self) -> int:
+        return len(self.files) + len(self.configs)
+
     def __str__(self):
         num_files = len(self.files)
         num_configs = len(self.configs)
